=============
Key Functions
=============

get_scores.py
-------------

.. autofunction:: gunc.get_scores.get_n_effective_surplus_clades
.. autofunction:: gunc.get_scores.expected_entropy_estimate
.. autofunction:: gunc.get_scores.calc_expected_conditional_entropy
.. autofunction:: gunc.get_scores.get_abundant_lineages_cutoff
.. autofunction:: gunc.get_scores.calc_contamination_portion
.. autofunction:: gunc.get_scores.calc_mean_hit_identity
.. autofunction:: gunc.get_scores.calc_conditional_entropy
.. autofunction:: gunc.get_scores.calc_clade_separation_score
.. autofunction:: gunc.get_scores.determine_adjustment
.. autofunction:: gunc.get_scores.is_chimeric
.. autofunction:: gunc.get_scores.get_scores_for_taxlevel
.. autofunction:: gunc.get_scores.chim_score

gunc.py
-------
.. autofunction:: gunc.gunc.merge_genecalls
.. autofunction:: gunc.gunc.split_diamond_output


checkm_merge.py
---------------
.. autofunction:: gunc.checkm_merge.merge_checkm_gunc


external_tools.py
-----------------
.. autofunction:: gunc.external_tools.prodigal
.. autofunction:: gunc.external_tools.diamond
.. autofunction:: gunc.external_tools.get_record_count_in_fasta
